#ifndef NT2_INCLUDE_FUNCTIONS_LOG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOG_HPP_INCLUDED

#include <nt2/exponential/include/functions/log.hpp>

#endif
